@@ -1,5 +1,11 @@
 from typing import List
 
+from pullenti.ner.ProcessorService import ProcessorService
+from pullenti.ner.SourceOfAnalysis import SourceOfAnalysis
+from pullenti.ner.keyword.KeywordType import KeywordType
+from pullenti.ner.keyword.KeywordReferent import KeywordReferent
+from pullenti.ner.keyword.KeywordAnalyzer import KeywordAnalyzer
+from pullenti.Sdk import Sdk
 from gensim.corpora.dictionary import Dictionary
 from gensim.models.tfidfmodel import TfidfModel
 from gensim.utils import simple_preprocess
@@ -11,6 +17,13 @@ from srsparser.sections_tree import SectionsTree
 
 morph = MorphAnalyzer()
 
+# инициализация - необходимо проводить один раз до обработки текстов
+print("Initializing SDK Pullenti ver {0} ({1}) ... ".format(Sdk.get_version(), Sdk.get_version_date()), end="",
+      flush=True)
+# инициализируются движок и все имеющиеся анализаторы
+Sdk.initialize_all()
+print("OK! version {0}".format(ProcessorService.get_version()), flush=True)
+
 
 def remove_stop_words(words: List[str]) -> List[str]:
     """
@@ -62,65 +75,6 @@ def tokenize(text: str, part_of_speech='') -> List[str]:
     return tokens
 
 
-def get_tf_idf_weights(documents: List[str], part_of_speech='') -> list:
-    """
-    Builds TF-IDF model for the documents and returns TF-IDF weights.
-
-    If parameter `part_of_speech` is stated,
-    then during text preprocessing all parts of speech, except `part_of_speech`, will be excluded from the documents.
-
-    :param documents: text units, for example, a word, phrase, sentence.
-    :param part_of_speech: part of speech acronym (see notation for grammem in pymorphy2 package).
-    :return: TF-IDF weight list for the documents.
-    """
-    # tokenize the documents
-    tokenized = [tokenize(document, part_of_speech) for document in documents]
-
-    # make dictionary (unique token list)
-    dictionary = Dictionary(tokenized)
-
-    # convert the dictionary to bag of words
-    bow_corpus = [dictionary.doc2bow(doc, allow_update=True) for doc in tokenized]
-
-    tf_idf = TfidfModel(bow_corpus, smartirs='ntc')
-
-    tf_idf_weights = []
-    for structure in tf_idf[bow_corpus]:
-        structure.sort(key=lambda item: item[1], reverse=True)
-
-        tf_idf_weight = []
-        for id, freq in structure:
-            tf_idf_weight.append([dictionary[id], around(freq, decimals=3)])
-
-        tf_idf_weights.append(tf_idf_weight)
-
-    return tf_idf_weights
-
-
-def get_sections_tf_idf_weights(structures: List[dict], section_name='Техническое задание', part_of_speech='') -> list:
-    """
-    Builds TF-IDF model for the software requirements specifications (SRS) structures content
-    and returns TF-IDF weights.
-
-    If parameter `part_of_speech` is stated, then during text preprocessing all parts of speech,
-    except `part_of_speech`, will be excluded from the structures content.
-
-    :param structures: the SRS structure list, which were filled relevant text documents content.
-    :param section_name: the name of the section of the SRS structure,
-        relative to which the content will be allocated from each SRS structures.
-    :param part_of_speech: part of speech acronym (see notation for grammem in pymorphy2 package).
-    :return: TF-IDF weight list for the SRS structures.
-    """
-    documents: List[str] = []
-    for structure in structures:
-        doc_structure = SectionsTree(structure)
-        structure_content = doc_structure.get_content(section_name)
-
-        documents.append(structure_content)
-
-    return get_tf_idf_weights(documents, part_of_speech)
-
-
 def strings_similarity(s1: str, s2: str) -> float:
     """
     Calculates strings similarity ratio for `s1` and `s2`.
@@ -156,3 +110,85 @@ def strings_similarity(s1: str, s2: str) -> float:
     cosine_similarity_ratio = c / float((sum(l1) * sum(l2)) ** 0.5)
 
     return cosine_similarity_ratio
+
+
+def get_tf_idf_weights(documents: List[str], part_of_speech='') -> list:
+    """
+    Builds TF-IDF model for the documents and returns TF-IDF weights.
+
+    If parameter `part_of_speech` is stated,
+    then during text preprocessing all parts of speech, except `part_of_speech`, will be excluded from the documents.
+
+    :param documents: text units, for example, a word, phrase, sentence.
+    :param part_of_speech: part of speech acronym (see notation for grammem in pymorphy2 package).
+    :return: TF-IDF weight list for the documents.
+    """
+    # tokenize the documents
+    tokenized = [tokenize(document, part_of_speech) for document in documents]
+
+    # make dictionary (unique token list)
+    dictionary = Dictionary(tokenized)
+
+    # convert the dictionary to bag of words
+    bow_corpus = [dictionary.doc2bow(doc, allow_update=True) for doc in tokenized]
+
+    tf_idf = TfidfModel(bow_corpus, smartirs='ntc')
+
+    tf_idf_weights = []
+    for structure in tf_idf[bow_corpus]:
+        structure.sort(key=lambda item: item[1], reverse=True)
+
+        tf_idf_weight = []
+        for id, freq in structure:
+            tf_idf_weight.append([dictionary[id], around(freq, decimals=3)])
+
+        tf_idf_weights.append(tf_idf_weight)
+
+    return tf_idf_weights
+
+
+def get_structures_tf_idf_weights(structures: List[dict],
+                                  section_name='Техническое задание',
+                                  part_of_speech='') -> list:
+    """
+    Builds TF-IDF model for the software requirements specifications (SRS) structures content
+    and returns TF-IDF weights.
+
+    If parameter `part_of_speech` is stated, then during text preprocessing all parts of speech,
+    except `part_of_speech`, will be excluded from the structures content.
+
+    :param structures: the SRS structure list, which were filled relevant text documents content.
+    :param section_name: the name of the section of the SRS structure,
+        relative to which the content will be allocated from each SRS structures.
+    :param part_of_speech: part of speech acronym (see notation for grammem in pymorphy2 package).
+    :return: TF-IDF weight list for the SRS structures.
+    """
+    documents: List[str] = []
+    for structure in structures:
+        doc_structure = SectionsTree(structure)
+        structure_content = doc_structure.get_content(section_name)
+
+        documents.append(structure_content)
+
+    return get_tf_idf_weights(documents, part_of_speech)
+
+
+def get_keywords_tf_idf(structures: List[dict],
+                        structure_idx: int,
+                        section_name='Техническое задание',
+                        part_of_speech='') -> List[str]:
+    tf_idf_weights = get_structures_tf_idf_weights(structures, section_name, part_of_speech)
+    return [tf_idf_weight[0] for tf_idf_weight in tf_idf_weights[structure_idx]]
+
+
+def get_keywords_pullenti(structure: dict) -> List[str]:
+    sections_structure = SectionsTree(structure)
+    content = sections_structure.get_content()
+
+    keywords: List[str] = []
+    with ProcessorService.create_specific_processor(KeywordAnalyzer.ANALYZER_NAME) as proc:
+        ar = proc.process(SourceOfAnalysis(content), None, None)
+        for e0_ in ar.entities:
+            if isinstance(e0_, KeywordReferent) and e0_.child_words == 1 and e0_.typ != KeywordType.ANNOTATION:
+                keywords.append(e0_.to_string(short_variant=True).lower())
+    return keywords
